@@ -24,6 +24,7 @@ from dateutil.parser import ParserError
 
 from pylangacq.measures import _CLITIC, _get_ipsyn, _get_mlum, _get_mluw, _get_ttr
 from pylangacq.objects import Gra, Token, Utterance
+from pylangacq._clean_utterance import _clean_utterance
 
 
 _ENCODING = "utf-8"
@@ -119,11 +120,11 @@ def _params_in_docstring(*params, class_method=True):
     if "cls" in params:
         docstring += """
         cls : type, optional
-            Either :class:`~pylangacq.chat.Reader` (the default),
+            Either :class:`~pylangacq.Reader` (the default),
             or a subclass from it that expects the same arguments for the methods
             :func:`~pylangacq.Reader.from_zip`, :func:`~pylangacq.Reader.from_dir`,
             and :func:`~pylangacq.Reader.from_files`.
-            Pass in your own :class:`~pylangacq.chat.Reader` subclass
+            Pass in your own :class:`~pylangacq.Reader` subclass
             for new or modified behavior of the returned reader object."""
 
     if not class_method:
@@ -320,7 +321,7 @@ class Reader:
 
         Returns
         -------
-        Reader
+        :class:`pylangacq.Reader`
         """
         return self._pop("right")
 
@@ -329,7 +330,7 @@ class Reader:
 
         Returns
         -------
-        Reader
+        :class:`pylangacq.Reader`
         """
         return self._pop("left")
 
@@ -694,7 +695,7 @@ class Reader:
     def mlu(self, participant="CHI") -> List[float]:
         """Return the mean lengths of utterance (MLU).
 
-        This method is equivalent to :func:`~pylangacq.chat.Reader.mlum`.
+        This method is equivalent to :func:`~pylangacq.Reader.mlum`.
 
         Parameters
         ----------
@@ -726,15 +727,19 @@ class Reader:
         )
 
     def ttr(self, keep_case=True, participant="CHI") -> List[float]:
-        """Return the type-token ratios.
+        """Return the type-token ratios (TTR).
 
         Parameters
         ----------
         keep_case : bool, optional
-            If ``True``, case distinctions are kept, e.g.,
+            If ``True`` (the default), case distinctions are kept, e.g.,
             word tokens like "the" and "The" are treated as distinct.
-            If ``False`` (the default), all word tokens are forced to be in lowercase
+            If ``False``, all word tokens are forced to be in lowercase
             as a preprocessing step.
+            CHAT data from CHILDES intentionally does not follow the orthographic
+            convention of capitalizing the first letter of a sentence in the
+            transcriptions (as would have been done in many European languages),
+            and so leaving keep_case as True is appropriate in most cases.
         participant : str, optional
             Participant of interest, which defaults to the typical use case of ``"CHI"``
             for the target child.
@@ -856,7 +861,7 @@ class Reader:
 
         Returns
         -------
-        Reader
+        :class:`pylangacq.Reader`
         """
         strs = list(strs)
         if ids is None:
@@ -890,7 +895,7 @@ class Reader:
 
         Returns
         -------
-        Reader
+        :class:`pylangacq.Reader`
         """
 
         # Inner function with file closing and closure to wrap in the given encoding
@@ -934,7 +939,7 @@ class Reader:
 
         Returns
         -------
-        Reader
+        :class:`pylangacq.Reader`
         """
 
         file_paths = []
@@ -973,7 +978,7 @@ class Reader:
 
         Returns
         -------
-        Reader
+        :class:`pylangacq.Reader`
         """
         with contextlib.ExitStack() as stack:
             temp_dir = stack.enter_context(tempfile.TemporaryDirectory())
@@ -1311,15 +1316,15 @@ def read_chat(
     path : str
         A path that points to one of the following:
 
-        - ZIP file. Either a local file path or a URL (one that begins with
+        - ZIP file. Either a local ``.zip`` file path or a URL (one that begins with
           ``"https://"`` or ``"http://"``).
           Example of a URL: ``"https://childes.talkbank.org/data/Eng-NA/Brown.zip"``
         - A local directory, for files under this directory recursively.
-        - A single CHAT file.
+        - A single ``.cha`` CHAT file.
 
     Returns
     -------
-    :class:`~pylangacq.chat.Reader`
+    :class:`~pylangacq.Reader`
     """
     if cls != Reader and not issubclass(cls, Reader):
         raise TypeError(f"Only a Reader class or its child class is allowed: {cls}")
@@ -1327,9 +1332,10 @@ def read_chat(
     # Just in case the user provides a CHILDES web link like
     # https://childes.talkbank.org/access/Eng-NA/Brown.html
     # instead of https://childes.talkbank.org/data/Eng-NA/Brown.zip.
-    # The "childes" subdomain could sometimes be "phonbank" (and something else?).
+    # The subdomain can be "childes", "phonbank", "ca", etc.
     # This hack is just for convenience.
-    # Not sure if we should encourage using the .html link...
+    # Not sure if we should encourage using the .html link,
+    # since I can't guarantee the URL format...
     if re.search(r"https://\S+\.talkbank\.org/access/\S+\.html", path):
         path = path.replace("/access/", "/data/")
         path = path.replace(".html", ".zip")
@@ -1344,256 +1350,10 @@ def read_chat(
     else:
         raise ValueError(
             "path is not one of the accepted choices of "
-            f"{{zip file, local directory, `.cha` file}}: {path}"
+            f"{{.zip file, local directory, .cha file}}: {path}"
         )
 
 
-def _clean_utterance(utterance, phon=False):
-    """Filter away the CHAT-style annotations in ``utterance``.
-
-    Parameters
-    ----------
-    utterance : str
-        The utterance as a str
-    phon : bool, optional
-        whether we are handling PhonBank data; defaults to ``False``.
-        If ``True``, words like "xxx" and "yyy" won't be removed.
-
-    Returns
-    -------
-    str
-    """
-    # Function tested with the following CHILDES datasets:
-    # 1) Brent, Brown, HSLLD, Kuczaj, MacWhinney, Valian in Eng-NA-MOR
-    # 2) YipMatthews in Biling
-    # 3) LeeWongLeung in EastAsian/Cantonese
-    # 4) CromptonPater, Goad, Inkelas, and Providence in PhonBank English
-
-    # *** At the end of each step, apply remove_extra_spaces(). ***
-
-    # Step 1: Remove unwanted scope elements (only the very certain cases)
-    # [= whatever] for explanations
-    # [x how_many_times] for collapses
-    # [+ whatever] for actions etc
-    # [* whatever] for error coding
-    # [=? whatever] for uncertain transcriptions
-    # [=! whatever] for actions etc
-    # [% whatever] for random noises?
-    # [- language_name] for using a non-dominant language
-    # [^ whatever] for complex local events
-    # whatever for audio/video time stamps? the  character is 0x15
-    # [<] and [>] for overlapping, including [<1], [>2] etc with numbers
-    # (2.), (3.5) etc for pauses
-    # [%act: whatever] for actions etc
-
-    # [?] for best guess
-    # ‹ and › used in conjunction with [?]
-    # [!] for stressing
-
-    # "[*] [/" replaced by "[/"
-    # "] [*]" replaced by "]"
-
-    # print('utterance:', utterance, type(utterance))
-
-    utterance = re.sub(r"\[= [^\[]+?\]", "", utterance)
-    utterance = re.sub(r"\[x \d+?\]", "", utterance)
-    utterance = re.sub(r"\[\+ [^\[]+?\]", "", utterance)
-    utterance = re.sub(r"\[\* [^\[]+?\]", "", utterance)
-    utterance = re.sub(r"\[=\? [^\[]+?\]", "", utterance)
-    utterance = re.sub(r"\[=! [^\[]+?\]", "", utterance)
-    utterance = re.sub(r"\[% [^\[]+?\]", "", utterance)
-    utterance = re.sub(r"\[- [^\[]+?\]", "", utterance)
-    utterance = re.sub(r"\[\^ [^\[]+?\]", "", utterance)
-    utterance = re.sub(r"[^]+?", "", utterance)
-    utterance = re.sub(r"\[<\d?\]", "", utterance)
-    utterance = re.sub(r"\[>\d?\]", "", utterance)
-    utterance = re.sub(r"\(\d+?\.?\d*?\)", "", utterance)
-    utterance = re.sub(r"\[%act: [^\[]+?\]", "", utterance)
-
-    utterance = re.sub(r"\[\?\]", "", utterance)
-    utterance = re.sub(r"\[\!\]", "", utterance)
-    utterance = re.sub(r"‹", "", utterance)
-    utterance = re.sub(r"›", "", utterance)
-
-    utterance = re.sub(r"\[\*\] \[/", "[/", utterance)
-    utterance = re.sub(r"\] \[\*\]", "]", utterance)
-
-    utterance = _remove_extra_spaces(utterance)
-    # print('step 1:', utterance)
-
-    # Step 2: Pad elements with spaces to avoid human transcription errors
-    # If utterance has these delimiters: [ ]
-    # then pad them with extra spaces to avoid errors in transcriptions
-    # like "movement[?]" (--> "movement [?]")
-    #
-    # If utterance has:
-    #     < > (left and right angle brackets), excluding "+<" (lazy overlap)
-    #     “ (beginning quote)
-    #     ” (ending quote)
-    #     , (comma)
-    #     ? (question mark)
-    #     . (period) <-- commented out at the moment
-    #     (.) (short pause)
-    # then pad them with extra spaces.
-
-    utterance = re.sub(r"<", " <", utterance)
-    utterance = re.sub(r"\+ <", "+<", utterance)
-    utterance = re.sub(r">", "> ", utterance)
-    utterance = re.sub(r"\[", " [", utterance)
-    utterance = re.sub(r"\]", "] ", utterance)
-    utterance = re.sub(r"“", " “ ", utterance)
-    utterance = re.sub(r"”", " ” ", utterance)
-    utterance = re.sub(r",", " , ", utterance)  # works together with next line
-    utterance = re.sub(r"\+ ,", "+,", utterance)
-    utterance = re.sub(r"[^\[\./!]\?", " ? ", utterance)
-    # utterance = re.sub('[^\(\[\.\+]\.', ' . ', utterance)
-    utterance = re.sub(r"\(\.\)", " (.) ", utterance)
-    utterance = _remove_extra_spaces(utterance)
-    # print('step 2:', utterance)
-
-    # Step 3:
-    # Handle [/], [//], [///], [/?] for repetitions/reformulation
-    #        [: xx] or [:: xx] for errors
-    #
-    # Discard "xx [/]", "<xx yy> [/]", "xx [//]", "<xx yy> [//]".
-    # For "zz [: xx]" or "<yy zz> [:: xx]", keep "xx" and discard the rest.
-    #
-    # Strategies:
-    # 1. Get all matching index pairs for angle brackets < and >.
-    # 2. Delete the unwanted material inside and including these brackets
-    #    plus their signaling annotations (= "[:", "[::", "[/]", "[//]").
-    # 3. Delete the unwanted words on the left of the signaling annotations.
-
-    angle_brackets_l2r_pairs = {}  # left-to-right
-    for index_ in _find_indices(utterance, "<"):
-        counter = 1
-        for i in range(index_ + 1, len(utterance)):
-            if utterance[i] == "<":
-                counter += 1
-            elif utterance[i] == ">":
-                counter -= 1
-
-            if counter == 0:
-                angle_brackets_l2r_pairs[index_] = i
-                break
-    angle_brackets_r2l_pairs = {v: k for k, v in angle_brackets_l2r_pairs.items()}
-
-    index_pairs = []  # characters bounded by index pairs to be removed
-
-    # remove ' [///]'
-    triple_slash_right_indices = _find_indices(utterance, r"> \[///\]")
-    index_pairs += [(begin + 1, begin + 6) for begin in triple_slash_right_indices]
-
-    # remove ' [//]'
-    double_overlap_right_indices = _find_indices(utterance, r"> \[//\]")
-    index_pairs += [(begin + 1, begin + 5) for begin in double_overlap_right_indices]
-
-    # remove ' [/]'
-    single_overlap_right_indices = _find_indices(utterance, r"> \[/\]")
-    index_pairs += [(begin + 1, begin + 4) for begin in single_overlap_right_indices]
-
-    # remove ' [/?]'
-    slash_question_indices = _find_indices(utterance, r"> \[/\?\]")
-    index_pairs += [(begin + 1, begin + 4) for begin in slash_question_indices]
-
-    # remove ' [/-]'
-    slash_dash_indices = _find_indices(utterance, r"> \[/\-\]")
-    index_pairs += [(begin + 1, begin + 4) for begin in slash_dash_indices]
-
-    # remove ' [::'
-    double_error_right_indices = _find_indices(utterance, r"> \[::")
-    index_pairs += [(begin + 1, begin + 4) for begin in double_error_right_indices]
-
-    # remove ' [:'
-    single_error_right_indices = _find_indices(utterance, r"> \[: ")
-    index_pairs += [(begin + 1, begin + 3) for begin in single_error_right_indices]
-
-    right_indices = (
-        double_overlap_right_indices
-        + single_overlap_right_indices
-        + double_error_right_indices
-        + single_error_right_indices
-        + triple_slash_right_indices
-        + slash_question_indices
-        + slash_dash_indices
-    )
-
-    index_pairs = index_pairs + [
-        (angle_brackets_r2l_pairs[right], right) for right in sorted(right_indices)
-    ]
-    indices_to_ignore = set()
-    for left, right in index_pairs:
-        for i in range(left, right + 1):
-            indices_to_ignore.add(i)
-
-    new_utterance = ""
-    for i in range(len(utterance)):
-        if i not in indices_to_ignore:
-            new_utterance += utterance[i]
-    utterance = new_utterance
-
-    utterance = re.sub(r"\S+? \[/\]", "", utterance)
-    utterance = re.sub(r"\S+? \[//\]", "", utterance)
-    utterance = re.sub(r"\S+? \[///\]", "", utterance)
-    utterance = re.sub(r"\S+? \[/\?\]", "", utterance)
-    utterance = re.sub(r"\S+? \[/\-\]", "", utterance)
-
-    utterance = re.sub(r"\S+? \[::", "", utterance)
-    utterance = re.sub(r"\S+? \[:", "", utterance)
-
-    utterance = _remove_extra_spaces(utterance)
-    # print('step 3:', utterance)
-
-    # Step 4: Remove unwanted symbols
-    utterance = re.sub(r"“", "", utterance)
-    utterance = re.sub(r"”", "", utterance)
-
-    utterance = _remove_extra_spaces(utterance)
-
-    # Step 5: Split utterance by spaces and determine whether to keep items.
-
-    escape_prefixes = {
-        "[?",
-        "[/",
-        "[<",
-        "[>",
-        "[:",
-        "[!",
-        "[*",
-        '+"',
-        "+,",
-        "<&",
-    }
-    escape_words = {"0", "++", "+<", "+^", "(.)", "(..)", "(...)", ":", ";"}
-    keep_prefixes = {'+"/', "+,/", '+".'}
-
-    if not phon:
-        escape_words.update({"xxx", "yyy", "www", "xxx:", "yyy:"})
-        escape_prefixes.update({"&"})
-    else:
-        escape_words.update({","})
-        escape_prefixes.update({"0"})
-
-    words = utterance.split()
-    new_words = []
-
-    for word in words:
-        word = re.sub(r"\A<", "", word)  # remove beginning <
-        word = re.sub(r">\Z", "", word)  # remove final >
-        word = re.sub(r"\]\Z", "", word)  # remove final ]
-
-        not_an_escape_word = word not in escape_words
-        no_escape_prefix = not any(word.startswith(e) for e in escape_prefixes)
-        has_keep_prefix = any(word.startswith(k) for k in keep_prefixes)
-
-        if (not_an_escape_word and no_escape_prefix) or has_keep_prefix:
-            new_words.append(word)
-
-    # print('step 5:', remove_extra_spaces(' '.join(new_words)))
-
-    return _remove_extra_spaces(" ".join(new_words))
-
-
 def _clean_word(word):
     """Clean the word.
 
@@ -1622,38 +1382,6 @@ def _clean_word(word):
     return new_word
 
 
-def _remove_extra_spaces(inputstr):
-    """Remove extra spaces in *inputstr* so that there are only single spaces.
-
-    Parameters
-    ----------
-    inputstr : str
-
-    Returns
-    -------
-    str
-    """
-    while "  " in inputstr:
-        inputstr = inputstr.replace("  ", " ")
-    return inputstr.strip()
-
-
-def _find_indices(longstr, substring):
-    """Find all indices of non-overlapping ``substring`` in ``longstr``.
-
-    Parameters
-    ----------
-    longstr : str
-    substring : str
-
-    Returns
-    -------
-    list of int
-        List of indices of the long string for where substring occurs
-    """
-    return [m.start() for m in re.finditer(substring, longstr)]
-
-
 class _HTTPSession(requests.Session):
     def __init__(
         self, max_retries: int = 10, backoff_factor: float = 0.1, timeout: int = 60
